==> haskell-megaparsec-6.5.0-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 6.5.0
id: megaparsec-6.5.0-46t6qcyUEyl1nPYrqrn1Ze
key: megaparsec-6.5.0-46t6qcyUEyl1nPYrqrn1Ze
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: 529c04d74007be9d4e881bb447031396
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Expr Text.Megaparsec.Internal Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.4.3/site-local/megaparsec-6.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/megaparsec-6.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/megaparsec-6.5.0
hs-libraries: HSmegaparsec-6.5.0-46t6qcyUEyl1nPYrqrn1Ze
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 deepseq-1.4.3.0 mtl-2.2.2
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=7f9925423ee321de0651ba5e24e000f1
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-megaparsec-6.5.0-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: megaparsec
version: 6.5.0
id: megaparsec-6.5.0-G2WzgYCrs1lBNj5cEcU9K4
key: megaparsec-6.5.0-G2WzgYCrs1lBNj5cEcU9K4
license: BSD-2-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Megaparsec contributors,
        Paolo Martini <paolo@nemail.it>,
        Daan Leijen <daan@microsoft.com>
homepage: https://github.com/mrkkrp/megaparsec
synopsis: Monadic parser combinators
description:
    This is an industrial-strength monadic parser combinator library.
    Megaparsec is a feature-rich package that strikes a nice balance between
    speed, flexibility, and quality of parse errors.
category: Parsing
abi: 5351d8ca3bf428160f46fd0511026fdf
exposed: True
exposed-modules:
    Text.Megaparsec Text.Megaparsec.Byte Text.Megaparsec.Byte.Lexer
    Text.Megaparsec.Char Text.Megaparsec.Char.Lexer
    Text.Megaparsec.Error Text.Megaparsec.Error.Builder
    Text.Megaparsec.Expr Text.Megaparsec.Internal Text.Megaparsec.Perm
    Text.Megaparsec.Pos Text.Megaparsec.Stream
hidden-modules: Text.Megaparsec.Class Text.Megaparsec.State
import-dirs: /usr/lib/ghc-8.4.3/site-local/megaparsec-6.5.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/megaparsec-6.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/megaparsec-6.5.0
hs-libraries: HSmegaparsec-6.5.0-G2WzgYCrs1lBNj5cEcU9K4
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    containers-0.5.11.0 deepseq-1.4.3.0 mtl-2.2.2
    parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul text-1.2.3.0
    transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parser-combinators-1.0.0-FkDIkMqlFRy3ywBA26Y9ci=7f9925423ee321de0651ba5e24e000f1
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-megaparsec/html/megaparsec.haddock
haddock-html: /usr/share/doc/haskell-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
